==> blender-2.44.tar.gz: blender-2.44/extern/bullet2/src/BulletCollision/CollisionShapes/btSphereShape.h <==
/*
Bullet Continuous Collision Detection and Physics Library
Copyright (c) 2003-2006 Erwin Coumans  http://continuousphysics.com/Bullet/

This software is provided 'as-is', without any express or implied warranty.
In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, 
including commercial applications, and to alter it and redistribute it freely, 
subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
3. This notice may not be removed or altered from any source distribution.
*/

#ifndef SPHERE_MINKOWSKI_H
#define SPHERE_MINKOWSKI_H

#include "btConvexShape.h"
#include "BulletCollision/BroadphaseCollision/btBroadphaseProxy.h" // for the types

///btSphereShape implements an implicit (getSupportingVertex) Sphere
class btSphereShape : public btConvexShape

{
	
public:
	btSphereShape (btScalar radius);
	
	
	virtual btVector3	localGetSupportingVertex(const btVector3& vec)const;
	virtual btVector3	localGetSupportingVertexWithoutMargin(const btVector3& vec)const;
	//notice that the vectors should be unit length
	virtual void	batchedUnitVectorGetSupportingVertexWithoutMargin(const btVector3* vectors,btVector3* supportVerticesOut,int numVectors) const;


	virtual void	calculateLocalInertia(btScalar mass,btVector3& inertia);

	virtual void getAabb(const btTransform& t,btVector3& aabbMin,btVector3& aabbMax) const;

	virtual int	getShapeType() const { return SPHERE_SHAPE_PROXYTYPE; }

	btScalar	getRadius() const { return m_implicitShapeDimensions.getX();}

	//debugging
	virtual char*	getName()const {return "SPHERE";}

	virtual void	setMargin(float margin)
	{
		btConvexShape::setMargin(margin);
	}
	virtual float	getMargin() const
	{
		//to improve gjk behaviour, use radius+margin as the full margin, so never get into the penetration case
		//this means, non-uniform scaling is not supported anymore
		return m_localScaling.getX() * getRadius() + btConvexShape::getMargin();
	}


};


#endif //SPHERE_MINKOWSKI_H

==> blender-2.47.tar.gz: blender-2.47/extern/bullet2/src/BulletCollision/CollisionShapes/btSphereShape.h <==
/*
Bullet Continuous Collision Detection and Physics Library
Copyright (c) 2003-2006 Erwin Coumans  http://continuousphysics.com/Bullet/

This software is provided 'as-is', without any express or implied warranty.
In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, 
including commercial applications, and to alter it and redistribute it freely, 
subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
3. This notice may not be removed or altered from any source distribution.
*/

#ifndef SPHERE_MINKOWSKI_H
#define SPHERE_MINKOWSKI_H

#include "btConvexShape.h"
#include "../BroadphaseCollision/btBroadphaseProxy.h" // for the types

///btSphereShape implements an implicit (getSupportingVertex) Sphere
ATTRIBUTE_ALIGNED16(class) btSphereShape : public btConvexShape

{
	
public:
	btSphereShape (btScalar radius);
	
	
	virtual btVector3	localGetSupportingVertex(const btVector3& vec)const;
	virtual btVector3	localGetSupportingVertexWithoutMargin(const btVector3& vec)const;
	//notice that the vectors should be unit length
	virtual void	batchedUnitVectorGetSupportingVertexWithoutMargin(const btVector3* vectors,btVector3* supportVerticesOut,int numVectors) const;


	virtual void	calculateLocalInertia(btScalar mass,btVector3& inertia);

	virtual void getAabb(const btTransform& t,btVector3& aabbMin,btVector3& aabbMax) const;

	virtual int	getShapeType() const { return SPHERE_SHAPE_PROXYTYPE; }

	btScalar	getRadius() const { return m_implicitShapeDimensions.getX();}

	//debugging
	virtual char*	getName()const {return "SPHERE";}

	virtual void	setMargin(btScalar margin)
	{
		btConvexShape::setMargin(margin);
	}
	virtual btScalar	getMargin() const
	{
		//to improve gjk behaviour, use radius+margin as the full margin, so never get into the penetration case
		//this means, non-uniform scaling is not supported anymore
		return m_localScaling.getX() * getRadius() + btConvexShape::getMargin();
	}


};


#endif //SPHERE_MINKOWSKI_H
